==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>O plugin %1 não é compatível com o sistema.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Definições Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Ligar</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Definições Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 ligado</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>A ligar...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Desligado</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Adicionar esquema de teclado</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Data hora</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 horas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 horas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Definições horárias</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Ativar rede</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Desativar rede</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Definições de rede</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Tem a certeza que deseja eliminar %1 itens?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Esta ação não pode ser restabelecida</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Dispositivo desconhecido</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Volume desconhecido</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Desmontar tudo</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Lançador</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Modo Elegante</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Modo Eficiente</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Manter visível</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Manter oculta</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultar inteligente</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Localização</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Vista de Tarefas</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Remover da doca</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Desativar ligação por cabo</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Ativar ligação por cabo</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Desativar ligação sem fios</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Ativar ligação sem fios</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Desativar rede</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Ativar rede</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Definições de rede</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desativado</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Ligação sem fios: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Ligação por cabo: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Desligado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>A ligar</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Ligado mas sem acesso à Internet</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desligado</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sem fios</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rede por cabo</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Falha na ligação</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rede por cabo</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rede por cabo %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Definições de energia</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacidade %1, %2 min restantes</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacidade %1, %2 hr %3 min restantes</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>A carregar %1, %2 min até ficar carregada</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>A carregar %1, %2 hr %3 min até ficar carregada</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Carregado</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacidade %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>A carregar %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacidade %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacidade 1%, totalmente carregada</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Mostrar ambiente de trabalho</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Remover da doca</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Encerrar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Terminar sessão</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Mudar de conta</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Definições de energia</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Ativar som</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Definições de som</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volume %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Som</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Lixo</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Lixo - %1 ficheiro</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Lixo - %1 ficheiros</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Esvaziar</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Área de notificação do sistema</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sem fios</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rede sem fios %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.53.orig.tar.xz: dde-dock-5.5.53/translations/dde-dock_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>O plugin %1 não é compatível com o sistema.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo de avião</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Ligar</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Definições de modo de avião</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo de avião</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Definições Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Ligar</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Definições Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 ligado</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>A ligar...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Desligado</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Adicionar esquema de teclado</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Data hora</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 horas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 horas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Definições horárias</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Tem a certeza que deseja eliminar %1 itens?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Esta ação não pode ser restabelecida</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Dispositivo desconhecido</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Volume desconhecido</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Desmontar tudo</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Lançador</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Sair do Modo Seguro</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Doca - Modo Seguro</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>A Doca está em modo seguro, saia para a mostrar corretamente</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Modo Elegante</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Modo Eficiente</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Manter visível</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Manter oculta</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultar inteligente</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Localização</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Definições da doca</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Vários ecrãs</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Área de plugins</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Selecione quais os ícones que aparecem na Doca</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Modo Elegante</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Modo eficiente</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Localização</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Manter visível</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Manter ocultada</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Ocultação inteligente</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Pequeno</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Mostrar Doca</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>No ecrã onde está o cursor</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Apenas no ecrã principal</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Vista de Tarefas</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Remover da doca</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Definições de energia</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacidade %1, %2 min restantes</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacidade %1, %2 hr %3 min restantes</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>A carregar %1, %2 min até ficar carregada</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>A carregar %1, %2 hr %3 min até ficar carregada</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacidade %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>A carregar %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacidade %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacidade 1%, totalmente carregada</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Doca</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Mostrar ambiente de trabalho</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Remover da doca</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Encerrar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Terminar sessão</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Mudar de conta</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Definições de energia</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Ativar som</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Definições de som</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volume %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Som</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Lixo</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Lixo - %1 ficheiro</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Lixo - %1 ficheiros</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Mover para Lixo</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Esvaziar</translation>
    </message>
</context>
</TS>
